`PIEL`: Photonic and Integrated Electronic System Design Tools!
==============================================================

.. toctree::
   :maxdepth: 2
   :caption: Environment:

   readme
   installation
   integration
   examples
   usage
   sections/environment/index
   sections/codesign/index
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
